@@ -16,7 +16,7 @@ from oauthlib.oauth2 import BackendApplicationClient
 
 
 
-def run(argv):
+def main(argv):
     argv = sys.argv[1:]
     #log.debug('inforion ' + __version__)
     inputfile = ''
@@ -39,5 +39,5 @@ def run(argv):
 
 if __name__ == "__main__":
     #sys.exit(run("-h"))
-    run(sys.argv[1:])
+    main(sys.argv[1:])
 
